COIL: Rename "whitelist" in label_cleaner.py

Per go/coil, ChromeOS has a P1 Q3 OKR to remove oppressive language from
the code base, including replacing "whitelist" with "allowlist". This CL
addresses instances of "whitelist" in label_cleaner.py.

BUG=b:159917945
TEST=label_cleaner.py --dry-run

Change-Id: I719f604dbef25f599ae30f05b068c5046582f31e
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/autotest/+/2270510
Tested-by: Greg Edelston <gredelston@google.com>
Reviewed-by: Prathmesh Prabhu <pprabhu@chromium.org>
Reviewed-by: Xixuan Wu <xixuan@chromium.org>
Commit-Queue: Greg Edelston <gredelston@google.com>
diff --git a/site_utils/label_cleaner.py b/site_utils/label_cleaner.py
index 93de028..2b9e277 100755
--- a/site_utils/label_cleaner.py
+++ b/site_utils/label_cleaner.py
@@ -52,9 +52,9 @@
         'SKYLAB', 'respect_static_labels', type=bool, default=False)
 
 # Per-prefix metrics are generated only for the following prefixes. This
 # whitelist is a second level defence against populating the 'label_prefix'
 # field with arbitrary values provided on the commandline.
-_LABEL_PREFIX_METRICS_WHITELIST = (
+_LABEL_PREFIX_METRICS_ALLOWLIST = (
         'cros-version',
         'fwro-version',
         'fwrw-version',
@@ -196,7 +196,7 @@
     labels = fetch_labels(conn, options.label, options.prefix)
     logging.info('Found total %d labels matching %s', len(labels),
                  options.label)
-    if options.prefix and options.label in _LABEL_PREFIX_METRICS_WHITELIST:
+    if options.prefix and options.label in _LABEL_PREFIX_METRICS_ALLOWLIST:
         metrics.Gauge(_METRICS_PREFIX + '/total_labels_count').set(
                 len(labels),
                 fields={
@@ -52,9 +52,9 @@
 
 # Per-prefix metrics are generated only for the following prefixes. This
-# whitelist is a second level defence against populating the 'label_prefix'
+# allowlist is a second level defence against populating the 'label_prefix'
 # field with arbitrary values provided on the commandline.